@@ -24,18 +24,32 @@
 #include "debug.h"
 #include <string>
 #include <iostream>
+#include <glibmm/timer.h>
 
 /*
  *
  */
 static int debug_flags = SE_NO_DEBUG;
 
+/*
+ * PROFILING
+ */
+static bool profiling_enable = false;
+static Glib::Timer profiling_timer;
+static double profiling_timer_last = 0.0;
+
 /*
  *
  */
 void se_debug_init(int flags)
 {
 	debug_flags = flags;
+
+	if(G_UNLIKELY(debug_flags & SE_DEBUG_PROFILING) && debug_flags != SE_NO_DEBUG)
+	{
+		profiling_enable = true;
+		profiling_timer.start();
+	}
 }
 
 /*
@@ -60,7 +74,16 @@ void __se_debug(
 {
 	if(G_UNLIKELY(debug_flags & flag) || G_UNLIKELY(debug_flags & SE_DEBUG_ALL))
 	{
-		g_print("%s:%d (%s)\n", file, line, fonction);
+		if(profiling_enable)
+		{
+			double seconds = profiling_timer.elapsed();
+
+			g_print("[%f (%f)] %s:%d (%s)\n", seconds, seconds - profiling_timer_last, file, line, fonction);
+			profiling_timer_last = seconds;
+		}
+		else
+			g_print("%s:%d (%s)\n", file, line, fonction);
+
 		fflush(stdout);
 	}
 }
@@ -86,7 +109,16 @@ void __se_debug_message(
 		msg = g_strdup_vprintf(format, args);
 		va_end(args);
 
-		g_print("%s:%d (%s) %s\n", file, line, fonction, msg);
+		if(profiling_enable)
+		{
+			double seconds = profiling_timer.elapsed();
+
+			g_print("[%f (%f)] %s:%d (%s) %s\n", seconds, seconds - profiling_timer_last, file, line, fonction, msg);
+			profiling_timer_last = seconds;
+		}
+		else
+			g_print("%s:%d (%s) %s\n", file, line, fonction, msg);
+
 		fflush(stdout);
 
 		g_free(msg);
