@@ -23,35 +23,30 @@
 #include <iostream>
 #include <config.h>
 #include <gtkmm/main.h>
-#include "gui/Application.h"
-
-#include "debug.h"
-#include "DocumentSystem.h"
+#include "gui/application.h"
 #include "utility.h"
+#include "gtkmm_utility.h"
+#include "options.h"
 
 #include <ctime>
 #include <gst/gst.h>
 #include <gdk/gdkx.h>
 #include <glib.h>
-#include "Options.h"
 
 #ifdef ENABLE_GL
 	#include <gtkglmm.h>
 #endif//ENABLE_GL
 
-#ifdef ENABLE_UNITTEST
-	bool launch_unittest();
-#endif//ENABLE_UNITTEST
-
-#include "RegEx.h"
-
 /*
  *
  */
 void get_default_config(std::map<Glib::ustring, std::map<Glib::ustring, Glib::ustring> > &config)
 {
 	//[general]
-	config["general"]["automatically-open-video"] = "true";
+
+	//[document]
+	config["document"]["format"] = "SubRip";
+	config["document"]["newline"] = "Unix";
 
 	//[video-player]
 	config["video-player"]["display-translated-subtitle"] = "false";
@@ -71,31 +66,33 @@ void get_default_config(std::map<Glib::ustring, std::map<Glib::ustring, Glib::us
 	config["video-player"]["timeout"] = "100";
 	config["video-player"]["repeat"] = "false";
 	config["video-player"]["display"] = "false";
+	config["video-player"]["automatically-open-video"] = "true";
 
 	//[waveform]
 	config["waveform"]["zoom"] = "1";
 	config["waveform"]["scale"] = "1";
-	config["waveform"]["color-background"] = "#E6E6E6FF";
-	config["waveform"]["color-play-line"] = "#000000FF";
-	config["waveform"]["color-text"] = "#000000FF";
-	config["waveform"]["color-wave"] = "#00B300FF";
-	config["waveform"]["color-wave-fill"] = "#007F00FF";
-	config["waveform"]["color-marker"] = "#6666667F";
-	config["waveform"]["color-marker-hightlight"] = "#4C7FCF7F";
-	config["waveform"]["color-marker-invalid"] = "#FF00007F";
 	config["waveform"]["display-background"] = "false";
 	config["waveform"]["display-waveform-fill"] = "true";
-	config["waveform"]["display-subtitle-text"] = "true";
 	config["waveform"]["scrolling-with-player"] = "true";
 	config["waveform"]["scrolling-with-selection"] = "true";
 	config["waveform"]["respect-timing"] = "true";
 	config["waveform"]["display"] = "false";
+	config["waveform"]["renderer"] = "cairo";
+
+	//[waveform-renderer]
+	config["waveform-renderer"]["display-subtitle-text"]="true";
+	config["waveform-renderer"]["color-background"]="#4C4C4CFF";
+	config["waveform-renderer"]["color-wave"]="#99CC4CFF";
+	config["waveform-renderer"]["color-wave-fill"]="#FFFFFFFF";
+	config["waveform-renderer"]["color-subtitle"]="#994C1999";
+	config["waveform-renderer"]["color-subtitle-selected"]="#E57F4C99";
+	config["waveform-renderer"]["color-subtitle-invalid"]="#FFFF00CC";
+	config["waveform-renderer"]["color-text"]="#FFFFFFFF";
+	config["waveform-renderer"]["color-player-position"]="#FFFFFFFF";
 
 	//[interface]
 	config["interface"]["use-dynamic-keyboard-shortcuts"] = "true";
 	config["interface"]["maximize-window"] = "false";
-	config["interface"]["display-video-player"] = "false";
-	config["interface"]["display-waveform"] = "false";
 	config["interface"]["used-autosave"] = "false";
 	config["interface"]["ask-to-save-on-exit"] = "false";
 	config["interface"]["create-backup-copy"] = "false";
@@ -111,8 +108,9 @@ void get_default_config(std::map<Glib::ustring, std::map<Glib::ustring, Glib::us
 	config["subtitle-view"]["property-alignment-center"] = "false";
 	config["subtitle-view"]["show-character-per-line"] = "true";
 	config["subtitle-view"]["enable-rubberband-selection"] = "false";
-	config["subtitle-view"]["columns-display"] = "number;start;end;duration;text";
+	config["subtitle-view"]["columns-displayed"] = "number;start;end;duration;text";
 	config["subtitle-view"]["columns-list"] = "cps;duration;effect;end;layer;margin-l;margin-r;margin-v;name;note;number;start;style;text;translation";
+	config["subtitle-view"]["used-ctrl-enter-to-confirm-change"] = "false";
 
 	//[timing]
 	config["timing"]["min-characters-per-second"] = "5";
@@ -123,7 +121,7 @@ void get_default_config(std::map<Glib::ustring, std::map<Glib::ustring, Glib::us
 	config["timing"]["max-line-per-subtitle"] = "2";
 
 	//[external-video-player]
-	config["external-video-player"]["command"] = "mplayer \"#video_file\" -sub \"#subtitle_file\" -ss #seconds -osdlevel 2";
+	config["external-video-player"]["command"] = "mplayer \"#video_file\" -noautosub -sub \"#subtitle_file\" -ss #seconds -osdlevel 2";
 
 	//[dialog-check-errors]
 	config["dialog-check-errors"]["check-overlapping"] = "true";
@@ -162,10 +160,8 @@ void parse_debug_options(OptionGroup &op)
 			flags |= SE_DEBUG_APP;
 		if(op.debug_view)
 			flags |= SE_DEBUG_VIEW;
-		if(op.debug_loader)
-			flags |= SE_DEBUG_LOADER;
-		if(op.debug_saver)
-			flags |= SE_DEBUG_SAVER;
+		if(op.debug_io)
+			flags |= SE_DEBUG_IO;
 		if(op.debug_search)
 			flags |= SE_DEBUG_SEARCH;
 		if(op.debug_regex)
@@ -182,6 +178,8 @@ void parse_debug_options(OptionGroup &op)
 			flags |= SE_DEBUG_COMMAND;
 		if(op.debug_plugins)
 			flags |= SE_DEBUG_PLUGINS;
+		if(op.debug_profiling)
+			flags |= SE_DEBUG_PROFILING;
 
 		se_debug_init(flags);
 	}
@@ -202,9 +200,9 @@ int main(int argc, char *argv[])
 	std::clock_t start = std::clock();
 
 	// Bindtextdomain
-	bindtextdomain(PACKAGE, PACKAGE_LOCALE_DIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain(PACKAGE);
+	bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+	textdomain(GETTEXT_PACKAGE);
 
 	// init Gtk+
 	Gtk::Main kit(argc, argv);
@@ -250,15 +248,11 @@ int main(int argc, char *argv[])
 	
 	gst_init(&argc, &argv);
 
-#ifdef ENABLE_UNITTEST
-	if(options.launch_unittest)
-	{
-		return launch_unittest();
-	}
-#endif//ENABLE_UNITTEST
-	
 	// Run Application
-	Application*	application = utility::get_widget_derived<Application>("subtitleeditor.glade", "window-main");
+	Application*	application = gtkmm_utility::get_widget_derived<Application>(
+			SE_DEV_VALUE(PACKAGE_GLADE_DIR, PACKAGE_GLADE_DIR_DEV),
+			"subtitleeditor.glade", 
+			"window-main");
 
 	application->init(options);
 
