@@ -25,55 +25,28 @@
  
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <glibmm/ustring.h>
-#include <gdkmm/color.h>
+#include <gtkmm/window.h>
 #include <sstream>
 #include <iostream>
-
+#include "i18n.h"
 #include "debug.h"
 
-
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#include <glib/gi18n.h>
-	/*
-	#define _(String) gettext(String)
-	#ifdef gettext_noop
-	#define N_(String) gettext_noop(String)
-	#else
-	#define N_(String) (String)
-	#endif
-	*/
-#else /* NLS is disabled */
-	#define _(String) (String)
-	#define N_(String) (String)
-	#define textdomain(String) (String)
-	#define gettext(String) (String)
-	#define dgettext(Domain,String) (String)
-	#define dcgettext(Domain,String,Type) (String)
-	#define bindtextdomain(Domain,Directory) (Domain) 
-	#define bind_textdomain_codeset(Domain,Codeset) (Codeset) 
-#endif /* ENABLE_NLS */
-
+/*
+ * Return one of the values depending on whether 
+ * environment variable SE_DEV is defined or not.
+ */
+#define SE_DEV_VALUE(value, dev_value) ((Glib::getenv("SE_DEV") != "1") ? (value) : (dev_value))
+	
 
 /*
  *
  */
 Glib::ustring get_iso_name_for_lang_code(const Glib::ustring &code);
 
-/*
- *
- */
-void find_and_replace(Glib::ustring &text, const Glib::ustring &find, const Glib::ustring &replace);
-
-/*
- *	
- */
-Glib::ustring get_share_dir(const Glib::ustring &file);
-
 /*
  *	the profile name for the config dir
  *	~/config/subtitleeditor/{profile}
@@ -86,11 +59,6 @@ void set_profile_name(const Glib::ustring &profile);
  */
 Glib::ustring get_config_dir(const Glib::ustring &file);
 
-/*
- *
- */
-Glib::ustring check_end_char(const Glib::ustring &str);
-
 /*
  *	convertir str en n'importe quel type
  */
@@ -102,7 +70,8 @@ bool from_string(const std::string &src, T& dest)
 
 	bool state = s >> dest != 0;
 
-	se_debug_message(SE_DEBUG_UTILITY, "string:'%s' result:%s", src.c_str(), (state ? "true" : "false"));
+	if(!state)
+		se_debug_message(SE_DEBUG_UTILITY, "string:'%s'failed.", src.c_str());
 
 #ifdef DEBUG
 	g_return_val_if_fail(state, false);
@@ -121,7 +90,9 @@ bool from_string(const Glib::ustring &src, T& dest)
 
 	bool state = s >> dest != 0;
 
-	se_debug_message(SE_DEBUG_UTILITY, "string:'%s' result:%s", src.c_str(), (state ? "true" : "false"));
+	if(!state)
+		se_debug_message(SE_DEBUG_UTILITY, "string:'%s'failed.", src.c_str());
+
 #ifdef DEBUG
 	g_return_val_if_fail(state, false);
 #endif
@@ -156,44 +127,6 @@ void dialog_warning(const Glib::ustring &primary_text, const Glib::ustring &seco
 void dialog_error(const Glib::ustring &primary_text, const Glib::ustring &secondary_text);
 
 
-/*
- *	devired with glade 
- */
-
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/spinbutton.h>
-#include <libglademm/xml.h>
-
-class ComboBoxText : public Gtk::ComboBoxText
-{
-public:
-	ComboBoxText(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-	:Gtk::ComboBoxText(cobject)
-	{
-	}
-};
-
-/*
- *
- */
-class SpinButtonTiming : public Gtk::SpinButton
-{
-public:
-	SpinButtonTiming();
-	SpinButtonTiming(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
-
-	void set_use_negative(bool use_negative);
-
-	//SubtitleTime get_time();
-protected:
-	virtual int on_input(double *new_value);
-	virtual bool on_output();
-
-	virtual bool on_scroll_event(GdkEventScroll *ev);
-
-	virtual void on_insert_text(const Glib::ustring &str, int *pos);
-};
-
 namespace utility
 {
 	/*
@@ -220,6 +153,11 @@ namespace utility
 	 */
 	int string_to_int(const std::string &str);
 
+	/*
+	 *
+	 */
+	int string_to_long(const std::string &str);
+
 	/*
 	 *
 	 */
@@ -235,83 +173,42 @@ namespace utility
 	 */
 	void usplit(const Glib::ustring &str, const Glib::ustring::value_type &delimiter, std::vector<Glib::ustring> &container);
 
+	/*
+	 * Search and replace function. 
+	 */
+	void replace(Glib::ustring &text, const Glib::ustring &pattern, const Glib::ustring &replace_by);
+	
+	/*
+	 * Search and replace function. 
+	 */
+	void replace(std::string &text, const std::string &pattern, const std::string &replace_by);
+
 	/*
 	 *	transforme test/file.srt en /home/toto/test/file.srt 
 	 */
 	Glib::ustring create_full_path(const Glib::ustring &path);
 
 	/*
-	 *	est ce un chiffre
+	 * Get the number of characters per second.
+	 * msec = SubtitleTime::totalmsecs
 	 */
-	bool is_num(const Glib::ustring &str);
+	double get_characters_per_second(const Glib::ustring &text, const long msecs);
 
 	/*
-	 *	retourne le nombre de caractères par seconde
-	 *	msec = SubtitleTime::totalmsecs
+	 *	get number of characters for each line in the text
 	 */
-	int get_characters_per_second(const Glib::ustring &text, const long msecs);
-
+	std::vector<int> get_characters_per_line(const Glib::ustring &text);
 
 	/*
-	 *	crée et retourne un widget à partir d'un fichier glade
+	 * get a text stripped from tags
 	 */
-	template<class T>
-	T* get_widget_derived(const Glib::ustring &glade_file, const Glib::ustring &name)
-	{
-		se_debug_message(SE_DEBUG_UTILITY, "glade_file=<%s> name=<%s>", glade_file.c_str(), name.c_str());
-
-		T *dialog = NULL;
-
-		Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(get_share_dir("glade/" + glade_file));
-
-		refXml->get_widget_derived(name, dialog);
-
-		return dialog;
-	}
-}
-
-namespace Gst
-{
-	/*
-	 *	retourne le temps en string par rapport au temps nsecs (gstreamer)
-	 */
-	Glib::ustring time_to_string (gint64 time);
-
-	/*
-	 * Display a message for missing plugins.
-	 */
-	void dialog_missing_plugins(const std::list<Glib::ustring> &missings);
-
-	/*
-	 * Checks if the element exists and whether its version is at least the version required.
-	 * Display a dialog error if failed.
-	 */
-	bool check_registry(const Glib::ustring &name, int min_major, int min_minor, int min_micro);
-}
-
-/*
- *
- */
-namespace WidgetToConfig
-{
-	/*
-	 *
-	 */
-	void connect(Gtk::Widget *widget, const Glib::ustring &group, const Glib::ustring &key);
+	Glib::ustring get_stripped_text(const Glib::ustring &text);
 
 	/*
 	 *
 	 */
-	void read_config(Gtk::Widget *widget, const Glib::ustring &group, const Glib::ustring &key);
-
-	/*
-	 *
-	 */
-	void read_config_and_connect(
-													Gtk::Widget *widget, 
-													const Glib::ustring &group, 
-													const Glib::ustring &key);
+	void set_transient_parent(Gtk::Window &window);
+	
 }
 
-
 #endif//_utility_h
